# ScratchML
A python package with implementations of Machine Learning algorithms from scratch.

Contents
----
- [Algorithms Implemented](#algorithms-implemented)
- [Installing](#installing)

Algorithms Implemented:
----
### Regression:
1. *Simple Linear Regression* (`scratchml.regression.SimpleLinearRegression`)
2. *Multiple Linear Regression* (`scratchml.regression.MultipleLinearRegression`)

### Classification:
1. *Logistic Regression* (`scratchml.classification.LogisticRegression`)
2. *Support Vector Machine* (`scratchml.classification.SVM`)
3. *K-Nearest Neighbors* (`scratchml.classification.KNN`)

### Clustering:
1. *KMeans Clustering* (`scratchml.clustering.KMeans`)
1. *KMedoids Clustering* (`scratchml.clustering.KMedoids`)

Installing:
----
The project is available as a package on PyPI - [ScratchML](https://pypi.org/project/scratchml/)

To install it using pip:
`pip install scratchml`
